#
# spec file for package spec
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           clamtk
Version:        5.25
Release:        bp153.1.15
Summary:        GUI for the ClamAV Antivirus
License:        GPL-1.0+ or Artistic-1.0
Group:          Productivity/Security
Url:            https://github.com/dave-theunsub/clamtk
Source:         https://bitbucket.org/davem_/clamtk/downloads/clamtk-%{version}.tar.xz
Source1:        https://bitbucket.org/davem_/clamtk/downloads/clamtk-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Patch0:         clamtk-add_searchpath.patch
BuildRequires:  desktop-file-utils
# not actually needed, but to make the build fail if the dependencies
# won't be available at runtime:
BuildRequires:  perl(Cwd)
BuildRequires:  perl(Date::Calc)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  perl(Encode)
BuildRequires:  perl(File::Basename)
BuildRequires:  perl(File::Copy)
## BuildRequires:  perl(File::Find::Rule)
BuildRequires:  perl(File::Path)
BuildRequires:  perl(Glib)
BuildRequires:  perl(Gtk2) >= 1.241
BuildRequires:  perl(Gtk2::SimpleList)
#Obsoletes:      clamtk-kde
# for Virustotal API:
BuildRequires:  perl(JSON)
BuildRequires:  perl(LWP::Protocol::https)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Locale::gettext)
BuildRequires:  perl(Net::DNS)
BuildRequires:  perl(Text::CSV)
BuildRequires:  update-desktop-files
BuildRequires:  zenity
Requires:       clamav >= 0.88
Requires:       gnome-icon-theme
Requires:       perl(Cwd)
Requires:       perl(Digest::SHA)
Requires:       perl(Encode)
Requires:       perl(File::Basename)
Requires:       perl(File::Copy)
## Requires:       perl(File::Find::Rule)
Requires:       perl(File::Path)
Requires:       perl(Glib)
Requires:       perl(Gtk2) >= 1.241
Requires:       perl(Gtk2::SimpleList)
Requires:       perl(JSON)
Requires:       perl(LWP::Protocol::https)
Requires:       perl(LWP::UserAgent)
Requires:       perl(Locale::gettext)
Requires:       perl(Net::DNS)
Requires:       perl(Text::CSV)
Requires:       perl(Time::Piece)
Requires:       zenity
Recommends:     clamav-db
BuildArch:      noarch
%{perl_requires}

%description
ClamTk is a GUI front-end for ClamAV using Gtk2-perl.
It is designed to be an easy-to-use, point and click virus scanner.

%lang_package

%prep
%setup -q
%patch0

%build
gzip -dc clamtk.1.gz > clamtk.1
rm clamtk.1.gz

%install
install -D -m 0755 clamtk %{buildroot}%{_bindir}/clamtk
install -D -m 0644 images/clamtk.png %{buildroot}%{_datadir}/pixmaps/clamtk.png
install -D -m 0644 clamtk.1 %{buildroot}%{_mandir}/man1/clamtk.1

# Removed built-in help documentation until updated and translated. See upstream changelog 5.24
#install -d %%{buildroot}%%{_datadir}/help/C/clamtk
#install -d %%{buildroot}%%{_datadir}/help/C/clamtk/figures
#install -D -m 0644 help/C/clamtk/*.page %%{buildroot}%%{_datadir}/help/C/clamtk/
#install -D -m 0644 help/C/clamtk/figures/*.png %%{buildroot}%%{_datadir}/help/C/clamtk/figures/


# install in the perl vendorlib location:
install -d %{buildroot}/%{perl_vendorlib}/ClamTk
install -m0644 lib/*.pm %{buildroot}/%{perl_vendorlib}/ClamTk/

pushd po
for mo in *.mo; do
    lang="${mo%%.mo}"
    install -D -m 0644 ${mo} %{buildroot}%{_datadir}/locale/${lang}/LC_MESSAGES/%{name}.mo
done
popd #po
for l in cs_CZ el_GR nl_BE ast; do
    rm -rf %{buildroot}%{_datadir}/locale/$l
done

%suse_update_desktop_file -i -r %{name} System Security

%find_lang %{name} %{?no_lang_C}

%files
%doc CHANGES DISCLAIMER LICENSE README.md
# Removed built-in help documentation until updated and translated. See upstream changelog 5.24
#%%{_datadir}/help/C/%%{name}/
%{_bindir}/clamtk
%{perl_vendorlib}/ClamTk
%{_datadir}/pixmaps/clamtk.png
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/clamtk.1%{ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Nov  9 2017 sebix+novell.com@sebix.at
- update to 5.25
  * Remove forced white background (Github #51)
  * Update bitbucket path in various places
  * Use "other" for infobar button type (Github #51)
  * Updated language files: Chinese (zh_TW), Italian (it),
  English (en_AU), Dutch (nl), French (fr), Hungarian (hu),
    Swedish (sv)
- add source file validation
* Sun Jan  8 2017 ecsos@opensuse.org
- update to 5.24
  * Fix startup crash when icon theme lacks 'gtk-new' or other
    icon with Arch patch. Thanks to anthraxx. Closes BZ #1386370
  * Initial credits.md file showing contributors
  * Add comments line in About dialog to translation file
  * Removed built-in help documentation until updated
    and translated
  * Updated language files: Ukrainian (uk), Hebrew (he),
    English (en_UK), Galician (gl), Italian (it) Finnish (fi)
- changes from 5.23
  * Fix Github #67 (Directories not scanning under Linux Mint 18
    KDE [LiveUSB])
* Thu Sep 22 2016 ecsos@opensuse.org
- update to 5.22
  * Directories not scanning if users home includes /sys or
    /dev (Github #61).
  * Fix all of Github #59 (max-scansize)
  * Fix to names of whitelisted directories with extra ";"
  * Update website in About dialog as github.io
  * Begin digitally signing rpms again, like debs
  * Updated language files: pt_BR, en_AU, sv
- changes from 5.21
  * Update man pages to include updated URLs for bug reporting
  * Explicitly add archive scanning (Github #59)
  * Removed most monospacing as requested
  * Improved text layout
  * Updated language files: (ja), Indonesian (id), Polish (pl),
    Esperanto (eo), Spanish (es), Danish (da), Malay (ms)
* Sat Jan 23 2016 p.drouand@gmail.com
- Update to version 5.20
  * Remove nautilus as dependency for clamtk (BZ #1260284)
  * Updated language files: Khmer (km), Thai (th), Lao (lo),
    French (fr)
- Perform a spec-cleaner
- Add %%{perl_requires} macro
- Install perl libraries into %%{perl_vendorlib}
* Sun Jul 19 2015 ecsos@opensuse.org
- update to 5.19
  * Minor fix for History view and row selection (iter)
  * Minor tweak to improve display of objects scanned
  * Continue replacing Windows -> boxes
  * Updated language files: Korean (ko_KR), Italian (it)
* Tue May 12 2015 ecsos@opensuse.org
- update to 5.18
  * Improvements with Results window
  * Minor tweak on PUA-identified files
  * Add github bug reporting page to help documentation
  * Updated language files: Indonesian (id), Uzbek (uz),
    Finnish (fi), Ukrainian (uk), Galician (gl), German (de),
    Hebrew (he), English (en_UK), Chinese (zh_TW), Korean (ko_KR),
    Dutch (nl)
- changes from 5.17
  * Fix crash with Results window
  * Remove freecode references from help files
- changes from 5.16
  * Properly destroy Results window
  * Fix incorrect version in legacy build
  * Fix progressbar count issue for when recursive is
    not selected
  * Improve hidden files scanning/counting
  * Update website page to github
  * Updated language files: French (fr), Polish (pl)
* Fri Apr  3 2015 ecsos@opensuse.org
- update to 5.15
  * Speed up file count/progressbar when directory
    chosen for scanning is root (/) by switching to
    progressbar's activity mode (no %% complete)
  * Minor fix to keep window open after closing Results
    when main window is open
  * Fix window doesn't always show
  * Updated language files: Sinhalese (si), Croatian (hr),
    Dutch (nl)
- changes from 5.14
  * Add more meaningful progressbar back; requires
    File::Find (usually bundled, shouldn't add new requirements)
  * Fix language file text gets inserted into Update process
    for some ridiculous reason
  * Add more obvious notice for files that are too big to upload
    for Analysis (32MB limit through API)
  * Add more meaningful messages when trying to scan
    files/directories if user does not have permissions
  * Fix for when quit button requires more than one click
  * Minor font tweak to prevent words from being cut off
  * Updated language files: Finnish (fi), German (de),
    Ukrainian (uk), English (en_CA), English (en_AU),
    English (en_GB), Russian (ru), Galician (gl), Malay (ms),
    Romanian (ro), Chinese (zh_TW)
* Sat Jan 24 2015 ecsos@opensuse.org
- update to 5.13
  * Fix for submitting new files in Analysis
  * Update for Virustotal API return results
  * Fix closing Results window exits program
  * Fix "extra" translation in Scan finish
  * Fix Results window doesn't show in some situations
  * Fix scan statistics not resetting after scan
- changes from 5.12
  * Fix for mouse focus issue in history window
    (Google Issue #29)
  * Add delete keybinding to history window
  * Fix error with analysis function where incorrect
    results were given
  * Add initial support for Trash. Thanks, Nikita!
  * Fix formatting issue when quarantining or deleting
    items in the Results panel
* Wed Nov 19 2014 ecsos@opensuse.org
- insert requires: gnome-icon-theme because of crash
* Mon Nov 17 2014 ecsos@opensuse.org
- update to 5.11
  * Fix for clamtk.py to right-click scan files with
    special characters
  * Minor improvements to the Update dialog; the new benefit
    is one-click signature updating vice two
  * Minor updates to help documentation (PUAs)
  * Minor improvement in Update Assistant
  * Updated language files: German (de), Brazilian
    Portuguese (pt_BR), Bulgarian (bg)
- changes from 5.10
  * Display total number of signatures properly. Thanks, Natalia!
  * Main window opens centered, which seems to prevent some
    display issues. Thanks, John!
  * Updated language files: Dutch (nl), Slovak (sk),
    Indonesian (id), French (fr), Polish (pl), Italian (it),
    Romanian (ro)
- changes from  5.09
  * Release proper version for Ubuntu legacy (Google Issue #25).
    Thanks, Thom!
  * Fix check for updates issue due to change of ClamAV
    website
  * Updated language files: Uzbek (uz)
* Sun Aug 24 2014 ecsos@opensuse.org
- update to 5.08
  * Add missing proxy code (Google  Issue #20 ). Thanks, Uri!
  * Add the ability to submit files from results window
    to Virustotal
  * Minor tweak to improve redrawing of main window
  * Lots of language file updates
  * See all changes or check out the README
- added missing help
* Sun Jun 15 2014 ecsos@opensuse.org
- update to 5.07
  * Fix to make ClamTk show up again in Dash and
    other areas (clamtk.desktop);
    the OnlyShowIn portion from 5.06 removed it
  * Improve two tooltips in Settings panel
  * Minor fix to wording in Update panel
  * Standardize locale files permissions
  * Updated language files: Arabic (ar), German (de),
    Azerbaijani (az), English (en_AU), Galician (gl),
    French (fr), Tamil (ta), Ukrainian (uk), Uzbek (uz),
    Finnish (fi), Romanian (ro), Spanish (es), Hebrew (he),
    Asturian (ast), Czech (cz), Dutch (nl), Malay (ms), Slovak (sk)
* Wed May  7 2014 ecsos@opensuse.org
- added patch for visibilty in kde menu
* Mon May  5 2014 ecsos@opensuse.org
- update to 5.06
  * Add some extra arguments to scan to avoid scanning accidents
  * Actually remove zenity from dependencies (i.e.,
    from the build files); it was already removed from code in 5.05
  * Use ShowOnlyIn in .desktop file
  * Minor update for dpkg installation instructions in Help files
  * Minor display fix for the progressbar in the legacy version
    (Google Issue #17)
  * Temporary fix for incorrect text in Settings panel
  * Updated language files: Japanese (ja), Italian (it), German (de),
    Russian (ru), English (en_GB), Slovak (sk), Chinese (zh_TW)
  5.05 - Mar 14 2014
  * Preference to use single or double click in the
    main interface on the icons. No restart required
    (Google Issue #7)
  * Fix Analysis FileChooserButton reset issue (again).
    This time, ensure it is disabled after submitting
    a new file
  * Minor encoding fix for Scan.pm, Quarantine.pm.
  * Minor fix to use current version, not 5.00, in $ua
    (Analysis.pm)
  * Minor regex fix in selecting directories (GUI.pm)
  * Removed last remnants of Gtk2::Tooltips, which
    is deprecated
  * Remove zenity portion which has never been used.
  * Remove non-Italian strings from Italian (it) language file
  * Standardize some words in Update.pm
  * Minor cleanup
  * Updated language files: Slovak (sk), Chinese (zh_TW),
    Italian (it), Dutch (nl), Bulgarian (bg), Czech (cs_CZ),
    Ukrainian (uk), Uzbek (uz), German (de), Finnish (fi),
    Asturian (ast), Galician (gl), Spanish (es), French (fr),
    Portuguese (pt), Hebrew (he), Brazilian Portuguese (pt_BR),
    Malay (ms)
* Sun Feb 16 2014 ecsos@opensuse.org
- update to 5.04:
  * Clear combobox text area after action
    (Launchpad #1276125).
  * Search button active without filename and
    update analysis reports (Launchpad #1276141).
  * Fix update problem (Google Issue #4, Launchpad #1273165).
  * Updated language files:  Polish (pl), German (de),
    Bulgarian (bg), Azerbaijani (az), Spanish (es), Uzbek (uz)
* Sun Jan 19 2014 pascal.bleser@opensuse.org
- update to 5.03:
  * Re-add scheduler (Google Issue #1). This adds cron or cronie back as a dependency.
  * Update requirement for some distros to gnome-icon-theme-full, and
    gnome-icon-theme for some distros (Google Issue #2)
  * Remove extra gettext subs
  * Fix ugly copyright symbol
  * Minor help documentation and man page tweaks.
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- added missing requires for perl(Text::CSV), thanks to Gerrit Jan Eldering for
  reporting
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 5.02:
  * add gnome-icon-theme to requirements
  * update statusbar after saving update preferences
  * add missing icon in Nautilus context menu
  * remove unused (notify-send and more) code from App.pm
  * ensure FileChooserButton cannot be clicked with nothing (due to inability
    to reset)
  * remove deprecated encoding pragma
- changes from 5.01:
  * fix minimum Gtk2 version to >= 1.241
  * fix parsing issue on paths with spaces and special characters
  * update VT file size limit
  * correct quarantine sorting from lexical to spaceship operator (numerically
    ascending)
  * allow quarantine scrollwindow to actually scroll
  * results columns are now resizable
- changes from 5.00:
  * right-click file manager support; uses nautilus-python
  * use of Virustotal API; requires perl-JSON and perl-LWP-Protocol-https
  * now using Time::Piece instead of Date::Calc; it's a Perl built-in
  * now using Digest::SHA (sha256) instead of Digest::MD5
- changes from 4.46:
  * minor bug fix for recursive option
* Wed Aug  7 2013 pascal.bleser@opensuse.org
- update to 4.45:
  * fixed and improved submit file for analysis functionality
  * updated translations: ast, bg, hr, da_DK, fi, lt, pl, es, th
* Thu Apr 18 2013 meissner@suse.com
- updated to 4.44:
  * This version contains a minor fix, a couple improvements, and an updated
    language file.
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 4.42:
  * Added tooltips in scanning preferences for clarity
  * Removed unnecessary buttons in Prefs dialog
  * updated translations
* Sun Jun  3 2012 pascal.bleser@opensuse.org
- update to 4.41:
  * Actually remove File::Find::Rule from ClamTk sources, which should have
    been done in 4.40
* Sun May 27 2012 pascal.bleser@opensuse.org
- update to 4.40:
  * improvements to startup/scanning time, especially for full system scans
    (lp#697614)
  * removed "Ready" and "Elapsed time" fields: kind of pointless and makes the
    other two fields more clear
  * removed some debugging statements left from 4.39
  * update translations
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- update to 4.39:
  * Removed engine out of date warning. Worst. Thing. Ever.; removing Net::DNS
    as requirement and other minor things
  * Some utf-8 encoding fixes for Scheduler and Histories (lp#978566)
  * Added option to delete duplicate signature databases. Enabled by default.
  * Using sigtool to parse signature db files rather than manually. This way,
    if the format is changed, the information should still be valid
  * Added warning for when signature updates failed, which can happen when
    (e.g.) mirrors are not working
  * Updated localization.
* Thu Mar 29 2012 pascal.bleser@opensuse.org
- update to 4.38:
  * new icon
  * fix for crontab: note that you may have to delete and re-add your scheduled
    scan if this problem affected you
  * improvement for scanning from commandline
  * updated translations
* Sun Feb 12 2012 pascal.bleser@opensuse.org
- update to 4.37:
  * added drag and drop
  * fixed 1px line is left behind (lp#880148)
  * fix where the recursive option was not passed to the scanner
  * fix the count of files to be scanned (ClamAV does not scan empty files)
  * updated URLs for submitting malware and false positives to ClamAV
  * another minor improvement for the RTL override misery
  * more obvious context menu for results
  * more obvious notification during scanning start
* Sun Oct 16 2011 pascal.bleser@opensuse.org
- update to 4.36:
  * improvement for handling certain BiDi text malware (e.g., RTL override)
  * do not display Results window unless threats are found
  * keep Threats Found bolded if threats are found
  * minor fix to status bar display
  * icons removed from menubar
  * added Indonesian (id) language file
  * updated Slovak (sk_SK), English (en_BG) and Spanish (es)
* Mon Sep 26 2011 pascal.bleser@opensuse.org
- update to 4.35:
  * fix for very slow scanning affecting small number of users
  * fix toolbar to show all buttons, no arrow
  * minor fix to AV wizard
  * fix to elapsed timer not resetting after scans
  * updated translations: Malay (ms), Slovak (sk_SK), English (en_GB), Polish
    (pl), Bosnian (bs), German (de), Spanish (es)
* Thu Sep  8 2011 pascal.bleser@opensuse.org
- fix typo in patch, thanks to Heinz Pöpperl for reporting
* Sat Aug 20 2011 pascal.bleser@opensuse.org
- update to 4.34:
  * fix regular expression in scanning portion (LP#787864)
  * fix to display so that changing signature update method refreshes to show
    current signature status
  * fix to Last scan value
  * additional updates to clamtk.desktop file
  * many updated translations
* Sat Jun 11 2011 pascal.bleser@opensuse.org
- update to 4.33:
  * fixed parsing of AV signature dates: will now reflect status with date as a
    tooltip
  * sorting histories works again
  * fixed a mismatched tooltip (lp#790570)
  * minor gui improvements (buttons, placement, reflecting stats after AV
    wizard)
  * now using the most current date of signatures (cld vs cvd, if both exist)
  * no longer using .VIRUS extension for quarantined files: a fix is now in
    place to remove it from current files, and newly quarantined files will not
    use it at all
  * the formatting of saved virus logs has been improved
  * added a pound sign to allowed characters in virus filenames (as seen in
    recent UPS wave) for submission
  * started updating the .desktop file (ie., missing translations, minor fixes)
  * translation updates
* Mon Apr 25 2011 pascal.bleser@opensuse.org
- update to 4.32:
  * minor GUI improvements
  * new and updated language files
* Sun Jan  9 2011 pascal.bleser@opensuse.org
- update to 4.31:
  * minor fixes to quarantine restoration
  * added an extra check to ensure files reviewed in quarantine are regular
    files (and not directories)
  * added option to scan or ignore files under ~/.gvfs and ~/smb4k; by default,
    the option is ignore; we'll expand this as needed; the idea is to allow or
    disallow scanning of smb-mounted drives
  * scanning speed has been optimized by filtering unwanted directories and
    files prior to collection phase
  * AV wizard now has (Gtk2::)Assistant interface
  * new translations: ca_ES, fo
  * updated translations: gl, tr, hr, ko, es, nl, he, pt_BR, de, hu, nb, bg,
    pl, zh_CN, it, da_DK, bs, zh_TW
* Sun Nov  7 2010 pascal.bleser@opensuse.org
- update to 4.30:
  * adds the ability to submit files for analysis
* Sat Sep 11 2010 pascal.bleser@opensuse.org
- update to 4.29:
  * minor code cleanup
  * updated language files
* Thu Aug 19 2010 pascal.bleser@opensuse.org
- update to 4.28:
  * replaces hal with udev
  * contains minor code cleanup
  * updated language files
* Sat Jul 10 2010 pascal.bleser@opensuse.org
- update to 4.27:
  * adds an easy shortcut to scanning devices
  * contains minor improvements, code cleanup
  * language file updates.
* Sat May  1 2010 pascal.bleser@opensuse.org
- update to 4.26:
  * minor improvements
  * updated language files
* Sun Mar  7 2010 pascal.bleser@opensuse.org
- update to 4.25:
  * various documentation updates were made
  * when disambiguating a spec like foo::bar, where cat-1/pkg::foo
    and cat-2/pkg::bar exist, the implied preference for cat-2 is
    now recognized
  * a bug causing NoConfig clients to fail to find profiles when
    used with a supplemental repository that does not provide its
    own profiles description has been fixed
* Sun Feb 28 2010 pascal.bleser@opensuse.org
- update to 4.24:
  * minor bug fixes
  * a proxy configuration tab
  * a new icon
  * language file updates
* Wed Jan 20 2010 pascal.bleser@opensuse.org
- update to 4.23:
  * makes ClamTk more out-of-the-box ready
  * contains cleaned up code and numerous language file updates
* Sat Dec 26 2009 pascal.bleser@opensuse.org
- update to 4.22:
  * adds directory whitelisting
  * UI improvements
  * a few minor bugfixes
  * updated language files
* Sat Dec  5 2009 pascal.bleser@opensuse.org
- moved localization to -lang subpackage
* Sat Dec  5 2009 pascal.bleser@opensuse.org
- update to 4.21:
  * minor bug fix for loop count in updater
  * updated language files for nb, ar, da_DK, sl, ro and ja
* Tue Nov  3 2009 Sebastian Siebert <freespacer@gmx.de>
- add a patch to fix the problem with search path
* Sun Nov  1 2009 pascal.bleser@opensuse.org
- update to 4.20:
  * new "restore" feature: remembers a file's original place, so
    once quarantined, it can be returned if need be (e.g., a false
    positive)
  * sortable history views
  * updated language files
* Mon Sep 21 2009 pascal.bleser@opensuse.org
- update to 4.19:
  * adds a unified Preferences window with additional options
  * Bulgarian translation
* Fri Aug  7 2009 pascal.bleser@opensuse.org
- update to 4.18:
  * adds the ability to schedule daily scans and antivirus updates
  * adds an easy way to switch methods of updating antivirus updates
* Sat Jul 11 2009 pascal.bleser@opensuse.org
- update to 4.17:
  * minor cosmetic fix to avoid the perception that the program has
    stalled
  * the Danish and Brazilian Portuguese language files have been
    updated
* Sat Jun 20 2009 pascal.bleser@opensuse.org
- update to 4.16:
  * adds a recursive checkbox option to the main interface, which
    enables easier recursive scanning and allows the end user to
    save it as a startup option
  * minor GUI improvements
  * large number of language file additions and updates
* Fri Jun 12 2009 pascal.bleser@opensuse.org
- update to 4.15:
  * fixes a timeout issue which occurred occasionally during start
    up
  * adds Arabic language support
* Sun May 24 2009 pascal.bleser@opensuse.org
- update to 4.14:
  * fixes a crash which occurred when not connected to the Internet
  * the Chinese and Dutch language files updated
  * minor updates to the update dialogue
* Mon Apr 27 2009 pascal.bleser@opensuse.org
- update to 4.13:
  * adds Dutch (nl_BE) and Greek (el_GR) language files, with
    updates to the Romanian and Spanish language files
  * clamtk-kde is deprecated
* Sat Apr 25 2009 pascal.bleser@opensuse.org
- added missing Requires: zenity
* Sat Mar 21 2009 pascal.bleser@opensuse.org
- update to 4.12:
  * this release adds Turkish language support and updates the
    French, Brazilian, and Spanish language files
  * additionally, there are a few minor dependency changes
- clamtk-kde moved into its own package (clamtk-kde3)
* Wed Feb 18 2009 pascal.bleser@opensuse.org
- update to 4.11:
  * adds support for Slovak
  * updates translations for French, Korean and Spanish
* Sat Feb 14 2009 guru@unixtech.be
- update to 4.10:
  * fixes a situation where signatures were not accurately counted
  * some patches were re-added
* Sat Dec 27 2008 guru@unixtech.be
- update to 4.09:
  * updated language files
  * one minor bugfix related to language display
* Fri Dec 19 2008 guru@unixtech.be
- update to 4.08:
  * minor bugfixes
* Sat Dec  6 2008 guru@unixtech.be
- moved to openSUSE Build Service
- scrapped old %%changelog entries
- update to 4.07:
  * this release contains minor bugfixes involving the save-as dialog
* Thu Nov 27 2008 guru@unixtech.be
- update to 4.06:
  * fixes AV version detection
* Sat Nov 15 2008 guru@unixtech.be
- update to 4.05:
  * adds several minor bugfixes
  * updates the Slovene and Italian language files
* Sun Nov  9 2008 guru@unixtech.be
- update to 4.04:
  * fixes a minor bug
  * GUI improvements
  * updates to Chinese and Swedish translations
* Sat Oct 25 2008 guru@unixtech.be
- update to 4.03:
  * updates the Polish, French, Russian, and Brazilian language files to the
    4.x series
  * a few missing translation lines were added
  * the display of the GUI and the logs were improved
* Sat Oct 18 2008 guru@unixtech.be
- update to 4.02:
  * bugfixes
  * updated korean translation
* Sun Oct 12 2008 guru@unixtech.be
- update to 4.01:
  * bugfixes
  * updates README
  * updates Dutch translation
